from pinterest_dl import api, cli_parser, io, utils


def main():
    parser = cli_parser.get_parser()
    args = parser.parse_args()

    if args.cmd == "scrape":
        api.run_scrape(
            args.url,
            args.threshold,
            args.output,
            persistence=args.persistence,
            write=args.write,
            firefox=args.firefox,
            incognito=args.incognito,
            headless=args.headless,
            dry_run=args.dry_run,
            verbose=args.verbose,
            min_resolution=utils.parse_resolution(args.resolution) if args.resolution else None,
        )
        print("\nDone.")
    elif args.cmd == "download":
        img_list = io.read_json(args.url_list)
        downloaded_files = api.run_download(img_list, args.output, args.verbose)
        api.run_prune(downloaded_files, args.resolution)
        print("\nDone.")
    else:
        parser.print_help()


if __name__ == "__main__":
    main()



import argparse

from pinterest_dl import io, utils


# fmt: off
def get_parser():
    meta = io.read_json(utils.get_root().joinpath("manifest.json"))
    parser = argparse.ArgumentParser(description=meta["description"] + " v" + meta["version"])
    parser.add_argument("-v", "--version", action="version", version="v"+meta["version"])

    cmd = parser.add_subparsers(dest="cmd", help="Command to run")

    # scrape command
    scrape_cmd = cmd.add_parser("scrape", help="Scrape images from Pinterest")
    scrape_cmd.add_argument("url", help="URL to scrape images from")
    scrape_cmd.add_argument("-o", "--output", default="imgs", help="Output directory (default: imgs)")
    scrape_cmd.add_argument("-w", "--write", help="Write urls to json file")
    scrape_cmd.add_argument("-t", "--threshold", type=int, default=20, help="Number of scroll to perform (default: 20)")
    scrape_cmd.add_argument("-p", "--persistence", type=int, default=120, help="Time to wait for page to load (default: 120)")
    scrape_cmd.add_argument("-r", "--resolution", type=str, help="minimum resolution to keep (e.g. 512x512).")
    scrape_cmd.add_argument("--incognito", action="store_true", help="Incognito mode")
    scrape_cmd.add_argument("--dry-run", action="store_true", help="Run without download")
    scrape_cmd.add_argument("--firefox", action="store_true", help="Use Firefox browser")
    scrape_cmd.add_argument("--verbose", action="store_true", help="Print verbose output")
    scrape_cmd.add_argument("--headless", action="store_true", help="Run in headless mode")

    # download command
    download_cmd = cmd.add_parser("download", help="Download images")
    download_cmd.add_argument("url_list", help="Input file containing image urls")
    download_cmd.add_argument("-o", "--output", default="imgs", help="Output directory (default: imgs)")
    download_cmd.add_argument("-r", "--resolution", type=str, help="minimum resolution to keep (e.g. 512x512).")
    download_cmd.add_argument("--verbose", action="store_true", help="Print verbose output")

    return parser
# fmt: on



from pathlib import Path
from typing import List, Tuple

from pinterest_dl import downloader, io, scraper, utils


def run_download(
    img_urls: List[str | Path], output: str | Path, verbose: bool = False
) -> List[str | Path]:
    """download images concurrently with fallback urls

    Args:
        img_urls (List[str  |  Path]): list of image urls
        output (str | Path): output directory to save images
        verbose (bool, optional): print debug logs. Defaults to False.

    Returns:
        List[str  |  Path]: list of downloaded image paths
    """
    fallback_urls = [i.replace("/originals/", "/736x/") for i in img_urls]
    return downloader.download_concurrent_with_fallback(
        img_urls, output, fallback_urls, verbose=verbose
    )


def run_prune(local_images: List[str | Path], min_resolution: Tuple[int, int]):
    """prune images by resolution

    Args:
        local_images (List[str  |  Path]): list of image paths
        min_resolution (Tuple[int, int]): minimum resolution to keep
    """
    if min_resolution:
        for i in local_images:
            utils.prune_by_resolution(i, min_resolution)


def run_scrape(
    url: str,
    threshold: int,
    output: str | Path,
    persistence: int = 120,
    write: str | Path = None,
    firefox: bool = False,
    incognito: bool = False,
    headless: bool = False,
    dry_run: bool = False,
    verbose: bool = False,
    min_resolution: Tuple[int, int] = None,
):
    """extracts image urls from pinterest board and downloads them

    Args:
        url (str): input pinterest board url
        threshold (int): number of scroll to perform
        output (str | Path): output directory to save images
        persistence (int, optional): time to wait for page load. Defaults to 120.
        write (str | Path, optional): write image urls to json file. Defaults to None.
        firefox (bool, optional): use firefox browser. Defaults to False.
        incognito (bool, optional): use incognito mode. Defaults to False.
        dry_run (bool, optional): only print image urls. Defaults to False.
        verbose (bool, optional): print debug logs. Defaults to False.
        min_resolution (Tuple[int, int], optional): minimum resolution to keep. Defaults to None.
    """
    browser = scraper.Browser().Chrome(
        exe_path=utils.get_appdata_dir("chromedriver.exe"),
        incognito=incognito,
        headless=headless,
    )
    if firefox:
        browser = scraper.Browser().Firefox()
    try:
        pin_scraper = scraper.Pinterest(browser)
        img_urls = pin_scraper.scrape(
            url,
            threshold=threshold,
            presistence=persistence,
            verbose=verbose,
        )
    finally:
        browser.close()

    print(f"Found {len(img_urls)} urls")
    if write:
        io.write_json(img_urls, write, indent=4)
    if not dry_run:
        downloaded_files = run_download(img_urls, output, verbose)

        # post download
        run_prune(downloaded_files, min_resolution)
    else:
        for i in img_urls:
            print(i)
